# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rmessage.proto\x12\x0eproto.autobahn\"D\n\x0f\x41\x62stractMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\"e\n\x12ServerStateMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0e\n\x06topics\x18\x03 \x03(\t\"Z\n\x14ServerForwardMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"P\n\x0cTopicMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\x12\r\n\x05topic\x18\x02 \x01(\t\"c\n\x0ePublishMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"V\n\x12UnsubscribeMessage\x12\x31\n\x0cmessage_type\x18\x01 \x01(\x0e\x32\x1b.proto.autobahn.MessageType\x12\r\n\x05topic\x18\x02 \x01(\t*`\n\x0bMessageType\x12\x10\n\x0cSERVER_STATE\x10\x00\x12\x12\n\x0eSERVER_FORWARD\x10\x01\x12\x0b\n\x07PUBLISH\x10\x02\x12\r\n\tSUBSCRIBE\x10\x03\x12\x0f\n\x0bUNSUBSCRIBE\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MESSAGETYPE']._serialized_start=569
  _globals['_MESSAGETYPE']._serialized_end=665
  _globals['_ABSTRACTMESSAGE']._serialized_start=33
  _globals['_ABSTRACTMESSAGE']._serialized_end=101
  _globals['_SERVERSTATEMESSAGE']._serialized_start=103
  _globals['_SERVERSTATEMESSAGE']._serialized_end=204
  _globals['_SERVERFORWARDMESSAGE']._serialized_start=206
  _globals['_SERVERFORWARDMESSAGE']._serialized_end=296
  _globals['_TOPICMESSAGE']._serialized_start=298
  _globals['_TOPICMESSAGE']._serialized_end=378
  _globals['_PUBLISHMESSAGE']._serialized_start=380
  _globals['_PUBLISHMESSAGE']._serialized_end=479
  _globals['_UNSUBSCRIBEMESSAGE']._serialized_start=481
  _globals['_UNSUBSCRIBEMESSAGE']._serialized_end=567
# @@protoc_insertion_point(module_scope)
